==> haskell-microlens-aeson-2.5.2-144-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microlens-aeson
version:              2.5.2
visibility:           public
id:                   microlens-aeson-2.5.2-3ILhmBLrKfOHLgP770JVGU
key:                  microlens-aeson-2.5.2-3ILhmBLrKfOHLgP770JVGU
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson, (C) 2013 Edward A. Kmett, (C) 2015 Colin Woodbury

maintainer:           Colin Woodbury <colin@fosskers.ca>
author:               Colin Woodbury
homepage:             http://github.com/fosskers/microlens-aeson/
synopsis:             Law-abiding lenses for Aeson, using microlens
description:          Law-abiding lenses for Aeson, using microlens.
category:             Numeric
abi:                  ba023ec09f694b5267ab7386d391652e
exposed:              True
exposed-modules:      Lens.Micro.Aeson
hidden-modules:       Lens.Micro.Aeson.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/microlens-aeson-2.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/microlens-aeson-2.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/microlens-aeson-2.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-aeson
hs-libraries:         HSmicrolens-aeson-2.5.2-3ILhmBLrKfOHLgP770JVGU
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    bytestring-0.11.5.3 hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW text-2.0.2
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock

haddock-html:         /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-aeson-2.5.2-146-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microlens-aeson
version:              2.5.2
visibility:           public
id:                   microlens-aeson-2.5.2-BpWN3a3jMqTCsXX17HpzCZ
key:                  microlens-aeson-2.5.2-BpWN3a3jMqTCsXX17HpzCZ
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson, (C) 2013 Edward A. Kmett, (C) 2015 Colin Woodbury

maintainer:           Colin Woodbury <colin@fosskers.ca>
author:               Colin Woodbury
homepage:             http://github.com/fosskers/microlens-aeson/
synopsis:             Law-abiding lenses for Aeson, using microlens
description:          Law-abiding lenses for Aeson, using microlens.
category:             Numeric
abi:                  87481a2a87a8c70e007573366e974fe5
exposed:              True
exposed-modules:      Lens.Micro.Aeson
hidden-modules:       Lens.Micro.Aeson.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/microlens-aeson-2.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/microlens-aeson-2.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/microlens-aeson-2.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-aeson
hs-libraries:         HSmicrolens-aeson-2.5.2-BpWN3a3jMqTCsXX17HpzCZ
depends:
    aeson-2.2.0.0-Hqy1Zqe0ZE81dk2L20icmH
    attoparsec-0.14.4-8hLS1m777hPFjiaInp95BL base-4.18.2.1
    bytestring-0.11.5.3 hashable-1.4.7.0-LSmBhr9Bt59DsIlhOBFmCL
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    scientific-0.3.8.0-E8K90IhCZpR98POp8HwlML text-2.0.2
    vector-0.13.2.0-DULMVARQ1CU3TLBOg9xkS6

haddock-interfaces:
    /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock

haddock-html:         /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
